View source: R/sequence-inference.R
| declare_sequence_comparison_design | R Documentation |
Records the unit of assignment and the design under which a sequence-group contrast will be evaluated. Causal interpretation is permitted only for an explicitly randomized design and still depends on the validity of the study implementation.
declare_sequence_comparison_design(
group_col,
unit_col,
design = c("observational", "randomized", "paired_randomized"),
pair_col = NULL,
cluster_col = NULL
)
group_col |
Group or treatment column. |
unit_col |
Independent assignment or analysis-unit column. |
design |
|
pair_col |
Pair or block column required for paired randomization. |
cluster_col |
Optional higher-level assignment cluster. |
An object of class gp3_sequence_comparison_design.
declare_sequence_comparison_design("group", "participant_id",
design = "randomized")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.